@@ -13,7 +13,7 @@ sub new {
     $self->{name}      = $params{name};
     $self->{arguments} = $params{arguments};
     $self->{captures}  = $params{captures};
-    $self->{parent}    = undef;
+    $self->{parent}    = $params{parent};
 
     return $self;
 }
@@ -29,7 +29,12 @@ sub params { &captures }
 sub captures {
     my $self = shift;
 
-    return $self->{captures};
+    my $captures = $self->{captures};
+
+    return $self->parent ? {
+        %{$self->parent->captures},
+        %$captures
+    } : $captures;
 }
 
 sub name {
